@@ -1,8 +1,8 @@
 #!/usr/bin/env python3
 
-""" Smart Automatic Cover Art Downloader : search and download music album covers. """
+"""Smart Automatic Cover Art Downloader : search and download music album covers."""
 
-__version__ = "2.7.5"
+__version__ = "2.8.0"
 __author__ = "desbma"
 __license__ = "MPL 2.0"
 
@@ -39,9 +39,9 @@ async def search_and_download(
     out_filepath: str,
     *,
     size_tolerance_prct: int,
-    amazon_tlds: Sequence[str] = (),
     source_classes: Optional[Sequence[Any]] = None,
     preserve_format: bool = False,
+    convert_progressive_jpeg: bool = False,
 ) -> bool:
     """Search and download a cover, return True if success, False instead."""
     logger = logging.getLogger("Main")
@@ -52,9 +52,6 @@ async def search_and_download(
         source_classes = tuple(COVER_SOURCE_CLASSES.values())
     assert source_classes is not None  # makes MyPy chill
     cover_sources = [cls(*source_args) for cls in source_classes]
-    if sources.AmazonCdCoverSource in source_classes:
-        for tld in amazon_tlds:
-            cover_sources.append(sources.AmazonCdCoverSource(*source_args, tld=tld))
 
     # schedule search work
     search_futures = []
@@ -100,6 +97,7 @@ async def search_and_download(
                 size_tolerance_prct,
                 out_filepath,
                 preserve_format=preserve_format,
+                convert_progressive_jpeg=convert_progressive_jpeg,
             )
         except Exception as e:
             logger.warning(f"Download of {result} failed: {e.__class__.__qualname__} {e}")
@@ -129,15 +127,6 @@ def setup_common_args(arg_parser: argparse.ArgumentParser) -> None:
                 Note that covers with size above or close to the target size will still be preferred
                 if available""",
     )
-    arg_parser.add_argument(
-        "-a",
-        "--amazon-sites",
-        nargs="+",
-        choices=sources.AmazonCdCoverSource.TLDS[1:],
-        default=(),
-        dest="amazon_tlds",
-        help="""Amazon site TLDs to use as search source, in addition to amazon.com""",
-    )
     arg_parser.add_argument(
         "-s",
         "--cover-sources",
@@ -153,6 +142,12 @@ def setup_common_args(arg_parser: argparse.ArgumentParser) -> None:
         default=False,
         help="Preserve source image format if possible. Target format will still be prefered when sorting results.",
     )
+    arg_parser.add_argument(
+        "--convert-progressive-jpeg",
+        action="store_true",
+        default=False,
+        help="Convert progressive JPEG to baseline if needed. May result in bigger files and loss of quality.",
+    )
 
 
 def cl_main() -> None:
@@ -219,9 +214,9 @@ def cl_main() -> None:
         args.size,
         args.out_filepath,
         size_tolerance_prct=args.size_tolerance_prct,
-        amazon_tlds=args.amazon_tlds,
         source_classes=args.cover_sources,
         preserve_format=args.preserve_format,
+        convert_progressive_jpeg=args.convert_progressive_jpeg,
     )
     future = asyncio.ensure_future(coroutine)
     asyncio.get_event_loop().run_until_complete(future)
