@@ -1,8 +1,7 @@
-""" Sacad album cover. """
+"""Sacad album cover."""
 
 import asyncio
 import enum
-import imghdr
 import io
 import itertools
 import logging
@@ -13,6 +12,7 @@ import os
 import pickle
 import shutil
 import urllib.parse
+from typing import Dict
 
 import appdirs
 import bitarray
@@ -35,7 +35,6 @@ CoverImageFormat = enum.Enum("CoverImageFormat", ("JPEG", "PNG"))
 
 
 class CoverSourceQuality(enum.IntFlag):
-
     """Flags to describe cover source quality."""
 
     # whether or not the search query matching is fuzzy (does a typo return results ?)
@@ -61,7 +60,6 @@ class CoverSourceQuality(enum.IntFlag):
 
 
 class CoverImageMetadata(enum.IntFlag):
-
     """Flags to describe image metadata."""
 
     NONE = 0
@@ -83,7 +81,6 @@ def is_square(x):
 
 
 class CoverSourceResult:
-
     """Cover image returned by a source, candidate to be downloaded."""
 
     METADATA_PEEK_SIZE_INCREMENT = 2**12
@@ -166,20 +163,33 @@ class CoverSourceResult:
             s += f" [x{len(self.urls)}]"
         return s
 
-    async def get(self, target_format, target_size, size_tolerance_prct, out_filepath, *, preserve_format=False):
+    async def get(
+        self,
+        target_format: CoverImageFormat,
+        target_size: int,
+        size_tolerance_prct: float,
+        out_filepath: str,
+        *,
+        preserve_format: bool = False,
+        convert_progressive_jpeg: bool = False,
+    ) -> None:
         """Download cover and process it."""
         images_data = []
         for i, url in enumerate(self.urls):
             # download
             logging.getLogger("Cover").info(f"Downloading cover {url!r} (part {i + 1}/{len(self.urls)})...")
-            headers = {}
+            headers: Dict[str, str] = {}
             self.source.updateHttpHeaders(headers)
 
             async def pre_cache_callback(img_data):
                 return await __class__.crunch(img_data, self.format)
 
             store_in_cache_callback, image_data = await self.source.http.query(
-                url, headers=headers, verify=False, cache=__class__.image_cache, pre_cache_callback=pre_cache_callback
+                url,
+                headers=headers,
+                verify=False,
+                cache=__class__.image_cache,  # type: ignore
+                pre_cache_callback=pre_cache_callback,
             )
 
             # store immediately in cache
@@ -193,14 +203,18 @@ class CoverSourceResult:
             abs(max(self.size) - target_size) > target_size * size_tolerance_prct / 100
         )
         need_join = len(images_data) > 1
-        if (need_format_change and (not preserve_format)) or need_join or need_size_change:
+        need_post_process = (need_format_change and (not preserve_format)) or need_join or need_size_change
+        need_post_process = need_post_process or (
+            __class__.isProgressiveJpegData(images_data[0]) and convert_progressive_jpeg  # type: ignore
+        )
+        if need_post_process:
             # post process
             image_data = self.postProcess(
                 images_data, target_format if need_format_change else None, target_size if need_size_change else None
             )
 
             # crunch image again
-            image_data = await __class__.crunch(image_data, target_format)
+            image_data = await __class__.crunch(image_data, target_format)  # type: ignore
 
             format_changed = need_format_change
         else:
@@ -213,6 +227,16 @@ class CoverSourceResult:
         with open(out_filepath, "wb") as file:
             file.write(image_data)
 
+    @staticmethod
+    def isProgressiveJpegData(data: bytes) -> bool:
+        """Return True if data is from a progressive JPEG."""
+        in_bytes = io.BytesIO(data)
+        try:
+            img = PIL.Image.open(in_bytes)
+            return bool(img.info["progressive"])
+        except Exception:
+            return False
+
     def postProcess(self, images_data, new_format, new_size):
         """
         Convert image binary data.
@@ -560,8 +584,7 @@ class CoverSourceResult:
         try:
             img = PIL.Image.open(img_stream)
         except (IOError, OSError, RuntimeError):  # PIL.UnidentifiedImageError inherits from OSError
-            format = imghdr.what(None, h=img_data)
-            format = SUPPORTED_IMG_FORMATS.get(format, None)
+            pass
         else:
             format = img.format.lower()
             format = SUPPORTED_IMG_FORMATS.get(format, None)
