@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-""" Recursively search and download album covers for a music library. """
+"""Recursively search and download album covers for a music library."""
 
 import argparse
 import asyncio
@@ -36,7 +36,6 @@ Metadata = collections.namedtuple("Metadata", ("artist", "album", "has_embedded_
 
 # TODO use a dataclasses.dataclass when Python < 3.7 is dropped
 class Work:
-
     """Represent a single search & download work item."""
 
     def __init__(self, cover_filepath, audio_filepaths, metadata):
@@ -167,7 +166,7 @@ def get_dir_metadata(audio_filepaths, *, full_scan=False):
     return r
 
 
-VALID_PATH_CHARS = frozenset(r"-_.()!#$%&'@^{}~" + string.ascii_letters + string.digits)
+VALID_PATH_CHARS = frozenset(r"-_.()!#$%&'@^{}~" + string.ascii_letters + string.digits + " ")
 
 
 def sanitize_for_path(s):
@@ -288,7 +287,6 @@ def ichunk(iterable, n):
 def get_covers(work, args):
     """Get missing covers."""
     with contextlib.ExitStack() as cm:
-
         if args.cover_pattern == EMBEDDED_ALBUM_ART_SYMBOL:
             tmp_prefix = f"{os.path.splitext(os.path.basename(inspect.getfile(inspect.currentframe())))[0]}_"
             tmp_dir = cm.enter_context(tempfile.TemporaryDirectory(prefix=tmp_prefix))
@@ -358,9 +356,9 @@ def get_covers(work, args):
                     args.size,
                     cover_filepath,
                     size_tolerance_prct=args.size_tolerance_prct,
-                    amazon_tlds=args.amazon_tlds,
                     source_classes=args.cover_sources,
                     preserve_format=args.preserve_format,
+                    convert_progressive_jpeg=args.convert_progressive_jpeg,
                 )
                 future = asyncio.ensure_future(coroutine)
                 futures[future] = cur_work
