@@ -1,7 +1,5 @@
-""" SACAD cover sources. """
+"""SACAD cover sources."""
 
-from sacad.sources.amazoncd import AmazonCdCoverSource, AmazonCdCoverSourceResult  # noqa: F401
-from sacad.sources.amazondigital import AmazonDigitalCoverSource, AmazonDigitalCoverSourceResult  # noqa: F401
 from sacad.sources.deezer import DeezerCoverSource, DeezerCoverSourceResult  # noqa: F401
 from sacad.sources.discogs import DiscogsCoverSource, DiscogsCoverSourceResult  # noqa: F401
 from sacad.sources.itunes import ItunesCoverSource, ItunesCoverSourceResult  # noqa: F401
