@@ -1,4 +1,4 @@
-""" LastFM cover source. """
+"""LastFM cover source."""
 
 import collections
 import os.path
@@ -10,7 +10,6 @@ from sacad.sources.base import MAX_THUMBNAIL_SIZE, CoverSource
 
 
 class LastFmCoverSourceResult(CoverSourceResult):
-
     """LastFM cover search result."""
 
     def __init__(self, *args, **kwargs):
@@ -22,7 +21,6 @@ class LastFmCoverSourceResult(CoverSourceResult):
 
 
 class LastFmCoverSource(CoverSource):
-
     """
     Cover source using the official LastFM API.
 
@@ -62,7 +60,7 @@ class LastFmCoverSource(CoverSource):
         char_blacklist = frozenset(char_blacklist)
         return __class__.unpunctuate(s.lower(), char_blacklist=char_blacklist)
 
-    async def parseResults(self, api_data):
+    async def parseResults(self, api_data, *, search_album, search_artist):
         """See CoverSource.parseResults."""
         results = []
 
